diff --git a/.github/workflows/ci.yml b/.github/workflows/ci.yml
index 5c68ec1f..80dd2a8f 100644
--- a/.github/workflows/ci.yml
+++ b/.github/workflows/ci.yml
@@ -26,7 +26,7 @@ jobs:
         run: npm run lint
 
   test:
-    name: Test
+    name: Test (Node)
     runs-on: ${{ matrix.operating-system }}
     strategy:
       fail-fast: false
@@ -52,8 +52,15 @@ jobs:
       - name: Test
         run: npm run test
 
+      - name: Test (Integration)
+        # https://github.com/webpack/webpack/issues/14532
+        if: ${{ matrix.node-version != '17' }}
+        run: |
+          cd ./tests/integration/webpack-babel-test && ./test.sh && cd -
+          cd ./tests/integration/webpack-test && ./test.sh && cd -
+
   browser:
-    name: Browser Tests
+    name: Test (Browser)
     runs-on: 'ubuntu-latest'
     steps:
       - name: Checkout
diff --git a/tests/integration/multi-nodejs-test/package.json b/tests/integration/multi-nodejs-test/package.json
index 2fac51d2..6002c0ce 100644
--- a/tests/integration/multi-nodejs-test/package.json
+++ b/tests/integration/multi-nodejs-test/package.json
@@ -7,7 +7,7 @@
   "private": true,
   "license": "MIT",
   "dependencies": {
-    "handlebars": "file:../.."
+    "handlebars": "file:../../.."
   },
   "scripts": {
     "test": "node run-handlebars.js",
diff --git a/tests/integration/multi-nodejs-test/test.sh b/tests/integration/multi-nodejs-test/test.sh
index 77e358e2..1c692084 100755
--- a/tests/integration/multi-nodejs-test/test.sh
+++ b/tests/integration/multi-nodejs-test/test.sh
@@ -14,7 +14,7 @@ cd "$( dirname "$( readlink -f "$0" )" )" || exit 1
 unset npm_config_prefix
 
 echo "Handlebars should be able to run in various versions of NodeJS"
-for node_version_to_test in 0.10 0.12 4 5 6 7 8 9 10 11 12 13 14 15; do
+for node_version_to_test in 0.10 0.12 4 5 6 7 8 9 10 11 12 13 14 15 16 17; do
 
     rm target node_modules package-lock.json -rf
     mkdir target
diff --git a/tests/integration/webpack-babel-test/package.json b/tests/integration/webpack-babel-test/package.json
index dd21ae0a..14dd6176 100644
--- a/tests/integration/webpack-babel-test/package.json
+++ b/tests/integration/webpack-babel-test/package.json
@@ -12,7 +12,7 @@
     "@roundingwellos/babel-plugin-handlebars-inline-precompile": "^3.0.1",
     "babel-loader": "^8.0.6",
     "babel-plugin-istanbul": "^5.2.0",
-    "handlebars": "file:../..",
+    "handlebars": "file:../../..",
     "handlebars-loader": "^1.7.1",
     "nyc": "^14.1.1",
     "webpack": "^4.39.3",
diff --git a/tests/integration/webpack-test/package.json b/tests/integration/webpack-test/package.json
index 0940fe5f..d01e12d8 100644
--- a/tests/integration/webpack-test/package.json
+++ b/tests/integration/webpack-test/package.json
@@ -13,7 +13,7 @@
   "license": "ISC",
   "dependencies": {},
   "devDependencies": {
-    "handlebars": "file:../..",
+    "handlebars": "file:../../..",
     "handlebars-loader": "^1.7.1",
     "webpack": "^4.39.3",
     "webpack-cli": "^3.3.7"
